#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.Core;
using HeuristicLab.MainForm;
using HeuristicLab.Parameters.Views;

namespace HeuristicLab.Optimization.Views {
  [View("ResultParameter View")]
  [Content(typeof(ResultParameter<>), true)]
  [Content(typeof(IResultParameter<>), false)]
  public partial class ResultParameterView<T> : LookupParameterView<ResultCollection> where T : class, IItem, new() {

    public new IResultParameter<T> Content {
      get { return (IResultParameter<T>)base.Content; }
      set { base.Content = value; }
    }

    public ResultParameterView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.ResultNameChanged -= new EventHandler(Content_ResultNameChanged);
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.ResultNameChanged += new EventHandler(Content_ResultNameChanged);
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null)
        resultNameTextBox.Text = "-";
      else
        resultNameTextBox.Text = Content.ResultName;
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      resultNameTextBox.Enabled = Content != null;
      resultNameTextBox.ReadOnly = ReadOnly;
    }

    private void Content_ResultNameChanged(object sender, EventArgs e) {
      if (InvokeRequired)
        Invoke(new EventHandler(Content_ResultNameChanged), sender, e);
      else
        resultNameTextBox.Text = Content.ResultName;
    }

    private void resultNameTextBox_Validated(object sender, EventArgs e) {
      Content.ResultName = resultNameTextBox.Text;
    }
  }
}
